<?php
/**
 * Module Image
 *
 * @package Live Composer - WooCommerce integration
 */

// Prevent direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	header( 'HTTP/1.0 403 Forbidden' );
	exit;
}

/**
 * Module Class
 */
class LCWoo_Image extends DSLC_Module {

	/**
	 * Unique module id
	 *
	 * @var string
	 */
	var $module_id;

	/**
	 * Module label to show in the page builder
	 *
	 * @var string
	 */
	var $module_title;

	/**
	 * Module icon name (FontAwesome)
	 *
	 * @var string
	 */
	var $module_icon;

	/**
	 * Section in the modules panel that includes this module
	 *
	 * @var string
	 */
	var $module_category;

	/**
	 * Exclude from main listing
	 *
	 * @var string
	 */
	var $exclude_from_main_listing;

	/**
	 * Construct
	 */
	function __construct() {

		$this->module_id = 'LCWoo_Image';
		$this->module_title = __( 'Images', 'lc-woo-integration' );
		$this->module_icon = 'picture';
		$this->module_category = 'Woo Product';
		$this->exclude_from_main_listing = true;
	}

	/**
	 * Options
	 */
	function options() {

		$options = array(

			array(
				'label' => __( 'Show On', 'lc-woo-integration' ),
				'id' => 'css_show_on',
				'std' => 'desktop tablet phone',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Desktop', 'lc-woo-integration' ),
						'value' => 'desktop',
					),
					array(
						'label' => __( 'Tablet', 'lc-woo-integration' ),
						'value' => 'tablet',
					),
					array(
						'label' => __( 'Phone', 'lc-woo-integration' ),
						'value' => 'phone',
					),
				),
			),

			/**
			 * Styling
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo_product_images',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
			),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_main_border_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
			),
				array(
					'label' => __( 'Border Color', 'lc-woo-integration' ),
					'id' => 'css_border_color',
					'std' => '',
					'type' => 'color',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_product_images',
					'affect_on_change_rule' => 'border-color',
					'section' => 'styling',
				),
				array(
					'label' => __( 'Border Width', 'lc-woo-integration' ),
					'id' => 'css_border_width',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_product_images',
					'affect_on_change_rule' => 'border-width',
					'section' => 'styling',
					'ext' => 'px',
				),
				array(
					'label' => __( 'Borders', 'lc-woo-integration' ),
					'id' => 'css_border_trbl',
					'std' => 'top right bottom left',
					'type' => 'checkbox',
					'choices' => array(
						array(
							'label' => __( 'Top', 'lc-woo-integration' ),
							'value' => 'top',
						),
						array(
							'label' => __( 'Right', 'lc-woo-integration' ),
							'value' => 'right',
						),
						array(
							'label' => __( 'Bottom', 'lc-woo-integration' ),
							'value' => 'bottom',
						),
						array(
							'label' => __( 'Left', 'lc-woo-integration' ),
							'value' => 'left',
						),
					),
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_product_images',
					'affect_on_change_rule' => 'border-style',
					'section' => 'styling',
				),
				array(
					'label' => __( 'Border Radius', 'lc-woo-integration' ),
					'id' => 'css_border_radius',
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_product_images',
					'affect_on_change_rule' => 'border-radius',
					'section' => 'styling',
					'ext' => 'px',
				),
			array(
				'label' => __( 'Border', 'lc-woo-integration' ),
				'id' => 'css_main_border_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_main_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_main_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_product_images',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_main_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_product_images',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_main_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_product_images',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_main_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_product_images',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_main_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
			),

			/**
			 * Thumbnails
			 */

			array(
				'label' => __( 'Number of columns', 'lc-woo-integration' ),
				'id' => 'thumbnail_columns',
				'std' => '3',
				'type' => 'select',
				'refresh_on_change' => true,
				'section' => 'styling',
				'tab' => __( 'Thumbnails', 'lc-woo-integration' ),
				'choices' => array(
					array(
						'label' => __( 'One', 'lc-woo-integration' ),
						'value' => '1',
					),
					array(
						'label' => __( 'Two', 'lc-woo-integration' ),
						'value' => '2',
					),
					array(
						'label' => __( 'Three', 'lc-woo-integration' ),
						'value' => '3',
					),
					array(
						'label' => __( 'Four', 'lc-woo-integration' ),
						'value' => '4',
					),
				),
			),
			array(
				'label' => __( 'Opacity', 'lc-woo-integration' ),
				'id' => 'css_thumbnails_opacity',
				'std' => '.5',
				'type' => 'slider',
				'ext' => '',
				'min' => 0,
				'max' => 1,
				'increment' => 0.01,
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo_product_images .flex-control-nav li img',
				'affect_on_change_rule' => 'opacity',
				'section' => 'styling',
				'tab' => __( 'Thumbnails', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Opacity – on hover', 'lc-woo-integration' ),
				'id' => 'css_thumbnails_opacity_hover',
				'std' => '1',
				'type' => 'slider',
				'ext' => '',
				'min' => 0,
				'max' => 1,
				'increment' => 0.01,
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo_product_images .flex-control-nav li img:hover',
				'affect_on_change_rule' => 'opacity',
				'section' => 'styling',
				'tab' => __( 'Thumbnails', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Width', 'live-composer-page-builder' ),
				'id' => 'css_thumbnails_width',
				'std' => '90',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo_product_images .flex-control-nav li img',
				'affect_on_change_rule' => 'width',
				'section' => 'styling',
				'tab' => __( 'Thumbnails', 'lc-woo-integration' ),
				'ext' => '%',
				'min' => 0,
				'max' => 100,
				'increment' => 1,
			),
			array(
				'label' => __( 'Height', 'live-composer-page-builder' ),
				'id' => 'css_thumbnails_height',
				'std' => '50',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo_product_images .flex-control-nav li img',
				'affect_on_change_rule' => 'height',
				'section' => 'styling',
				'tab' => __( 'Thumbnails', 'lc-woo-integration' ),
				'ext' => '%',
				'min' => 0,
				'max' => 100,
				'increment' => 1,
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_thumbnails_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'styling',
				'tab' => __( 'Thumbnails', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_thumbnails_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_product_images .flex-control-nav li img',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Thumbnails', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_thumbnails_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_product_images .flex-control-nav li img',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Thumbnails', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_thumbnails_padding_bottom',
					'onlypositive' => true,
					'std' => '7',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_product_images .flex-control-nav li img',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Thumbnails', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_thumbnails_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_product_images .flex-control-nav li img',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'styling',
					'ext' => 'px',
					'tab' => __( 'Thumbnails', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_thumbnails_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'styling',
				'tab' => __( 'Thumbnails', 'lc-woo-integration' ),
			),

			/**
			 * Responsive: Tablet
			 */

			array(
				'label' => __( 'Responsive', 'lc-woo-integration' ),
				'id' => 'css_res_t',
				'std' => 'disabled',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => __( 'Disabled', 'lc-woo-integration' ),
						'value' => 'disabled',
					),
					array(
						'label' => __( 'Enabled', 'lc-woo-integration' ),
						'value' => 'enabled',
					),
				),
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_main_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_t_main_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_product_images',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_t_main_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_product_images',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_t_main_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_product_images',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_t_main_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_product_images',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Tablet', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_res_t_main_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Thumbnails - Width', 'live-composer-page-builder' ),
				'id' => 'css_res_t_thumbnails_width',
				'std' => '',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo_product_images .flex-control-nav li img',
				'affect_on_change_rule' => 'width',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => '%',
				'min' => 0,
				'max' => 100,
				'increment' => 1,
			),
			array(
				'label' => __( 'Thumbnails - Height', 'live-composer-page-builder' ),
				'id' => 'css_res_t_thumbnails_height',
				'std' => '',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo_product_images .flex-control-nav li img',
				'affect_on_change_rule' => 'height',
				'section' => 'responsive',
				'tab' => __( 'Tablet', 'lc-woo-integration' ),
				'ext' => '%',
				'min' => 0,
				'max' => 100,
				'increment' => 1,
			),

			/**
			 * Responsive Phone
			 */

			array(
				'label' => __( 'Responsive', 'lc-woo-integration' ),
				'id' => 'css_res_p',
				'std' => 'disabled',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => __( 'Disabled', 'lc-woo-integration' ),
						'value' => 'disabled',
					),
					array(
						'label' => __( 'Enabled', 'lc-woo-integration' ),
						'value' => 'enabled',
					),
				),
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_main_padding_group',
				'type' => 'group',
				'action' => 'open',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
				array(
					'label' => __( 'Padding Top', 'lc-woo-integration' ),
					'id' => 'css_res_p_main_padding_top',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_product_images',
					'affect_on_change_rule' => 'padding-top',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Right', 'lc-woo-integration' ),
					'id' => 'css_res_p_main_padding_right',
					'onlypositive' => true,
					'max' => 600,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_product_images',
					'affect_on_change_rule' => 'padding-right',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Bottom', 'lc-woo-integration' ),
					'id' => 'css_res_p_main_padding_bottom',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_product_images',
					'affect_on_change_rule' => 'padding-bottom',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
				array(
					'label' => __( 'Padding Left', 'lc-woo-integration' ),
					'id' => 'css_res_p_main_padding_left',
					'onlypositive' => true,
					'std' => '0',
					'type' => 'slider',
					'refresh_on_change' => false,
					'affect_on_change_el' => '.lcwoo_product_images',
					'affect_on_change_rule' => 'padding-left',
					'section' => 'responsive',
					'ext' => 'px',
					'tab' => __( 'Phone', 'lc-woo-integration' ),
				),
			array(
				'label' => __( 'Padding', 'lc-woo-integration' ),
				'id' => 'css_res_p_main_padding_group',
				'type' => 'group',
				'action' => 'close',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Thumbnails - Width', 'live-composer-page-builder' ),
				'id' => 'css_res_p_thumbnails_width',
				'std' => '',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo_product_images .flex-control-nav li img',
				'affect_on_change_rule' => 'width',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => '%',
				'min' => 0,
				'max' => 100,
				'increment' => 1,
			),
			array(
				'label' => __( 'Thumbnails - Height', 'live-composer-page-builder' ),
				'id' => 'css_res_p_thumbnails_height',
				'std' => '',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lcwoo_product_images .flex-control-nav li img',
				'affect_on_change_rule' => 'height',
				'section' => 'responsive',
				'tab' => __( 'Phone', 'lc-woo-integration' ),
				'ext' => '%',
				'min' => 0,
				'max' => 100,
				'increment' => 1,
			),
		);

		$options = array_merge( $options, $this->shared_options( 'animation_options' ) );
		$options = array_merge( $options, $this->presets_options() );

		return apply_filters( 'dslc_module_options', $options, $this->module_id );
	}

	/**
	 * Module HTML output.
	 *
	 * @param  array $options Module options to fill the module template.
	 */
	function output( $options ) {

		$this->module_start( $options );

		global $dslc_active;

		if ( isset( $_POST['dslc_post_id'] ) ) {
			$page_id = $_POST['dslc_post_id'];
		} elseif ( isset( $_GET['dslc_post_id'] ) ) {
			$page_id = $_GET['dslc_post_id'];
		} else {
			$page_id = get_the_ID();
		}

		if ( 'dslc_templates' === get_post_type() || ( $dslc_active && 'dslc_templates' === get_post_type( $page_id ) ) ) {
			if ( is_shop() || is_product_category() || is_product_tag() ) { ?>
				<div class="dslc-notification dslc-red">
					<?php esc_html_e( 'This module needs to be used just on the WooCommerce product pages only.', 'lc-woo-integration' ); ?>
				</div>
			<?php } else {

				/**
				 * If current page is Product template editng
				 * If LC editing mode is active ($dslc_active) it means we edit the product template
				 * in this case some of the modules like Product Thumbnails can't work,
				 * so we print a placehoder HTML for better user experience while editing template
				 */

				$placeholder_img_src = wc_placeholder_img_src();
				$columns = $options['thumbnail_columns'];

				echo '<div class="lcwoo_product_images">';
					echo '<div class="woocommerce-product-gallery woocommerce-product-gallery--columns-' . $columns . ' images">';
						echo '<div class="flex-viewport">';
							echo '<figure class="woocommerce-product-gallery__wrapper">';
								echo apply_filters( 'woocommerce_single_product_image_html', sprintf( '<img id="lcwoo_edit_mode_image" src="%s" alt="%s" />', $placeholder_img_src, __( 'Placeholder', 'woocommerce' ) ) );
							echo '</figure>';
						echo '</div>';

						// Product Thumbnails Placeholder.
						echo '<ol class="flex-control-nav flex-control-thumbs">';
							switch ( $columns ) {
								case 1:
									echo '<li><img src="' . $placeholder_img_src . '"></li>';
									echo '<li><img src="' . $placeholder_img_src . '"></li>';
									echo '<li><img src="' . $placeholder_img_src . '"></li>';
									echo '<li><img src="' . $placeholder_img_src . '"></li>';
									break;

								case 2:
									echo '<li><img src="' . $placeholder_img_src . '"></li>';
									echo '<li><img src="' . $placeholder_img_src . '"></li>';
									echo '<li><img src="' . $placeholder_img_src . '"></li>';
									echo '<li><img src="' . $placeholder_img_src . '"></li>';
									break;

								case 4:
									echo '<li><img src="' . $placeholder_img_src . '"></li>';
									echo '<li><img src="' . $placeholder_img_src . '"></li>';
									echo '<li><img src="' . $placeholder_img_src . '"></li>';
									echo '<li><img src="' . $placeholder_img_src . '"></li>';
									break;

								case 5:
									echo '<li><img src="' . $placeholder_img_src . '"></li>';
									echo '<li><img src="' . $placeholder_img_src . '"></li>';
									echo '<li><img src="' . $placeholder_img_src . '"></li>';
									echo '<li><img src="' . $placeholder_img_src . '"></li>';
									break;

								default:
									echo '<li><img src="' . $placeholder_img_src . '"></li>';
									echo '<li><img src="' . $placeholder_img_src . '"></li>';
									echo '<li><img src="' . $placeholder_img_src . '"></li>';
									echo '<li><img src="' . $placeholder_img_src . '"></li>';
									break;
							}
						echo '</ol>';
					echo '</div>';
				echo '</div>';
			}
		} else {

			if ( is_product() ) { ?>
				<div class="lcwoo_product_images">
					<?php

					global $lcwoo_product_thumbnails_columns;
					$lcwoo_product_thumbnails_columns = $options['thumbnail_columns'];
					add_filter( 'woocommerce_product_thumbnails_columns', function() { global $lcwoo_product_thumbnails_columns; return $lcwoo_product_thumbnails_columns; } );

					/**
					 * Front-end without LC in editing mode. Output the product image using standard WooCommerce function.
					 */
					woocommerce_show_product_images();

					?>
				</div>
			<?php } else {
				if ( $dslc_active ) {
				?>
					<div class="dslc-notification dslc-red">
						<?php esc_html_e( 'This module needs to be used just on the WooCommerce product pages only.', 'lc-woo-integration' ); ?>
					</div>
				<?php
				}
			}
		}

		$this->module_end( $options );

	}
}

/**
 * Register Module
 */
add_action('dslc_hook_register_modules',
	create_function( '', 'return dslc_register_module( "LCWoo_Image" );' )
);
