<?php
/**
 *  Plugin Name: Live Composer - WooCommerce integration
 *  Plugin URI: https://livecomposerplugin.com/downloads/woocommerce-page-builder/?utm_source=lc-woo-integration&utm_medium=wp-admin/plugins-list&utm_campaign=plugin_uri
 *  Description: Create a fully customizable WooCoomerce website using drag and drop builder.
 *  Version: 1.2.5
 *  Author: Live Composer Team
 *  Author URI: https://livecomposerplugin.com/?utm_source=lc-woo-integration&utm_medium=wp-admin/plugins-list&utm_campaign=author_uri
 *  License: GPL2
 *  License URI: https://www.gnu.org/licenses/gpl-2.0.html
 *  Domain Path: /lang
 *
 *  Live Composer - WooCommerce integration Plugin is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Live Composer - WooCommerce integration Plugin. If not, see <http://www.gnu.org/licenses/>.
 *
 *  @package Live Composer - WooCommerce integration
 */

// Prevent direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	header( 'HTTP/1.0 403 Forbidden' );
	exit;
}

/**
 * Run plugin only if the Live Composer and WooCommerce plugin is active
 */
function lcwoo_plugin_init() {

	if ( class_exists( 'WooCommerce' ) && class_exists( 'DSLC_Module' ) ) {

		$woocommerce_version = WC()->version;

		if ( version_compare( DS_LIVE_COMPOSER_VER, '1.3.9s', '>=' ) ) {

			if ( version_compare( $woocommerce_version, '3.0.0', '>=' ) ) {

				define( 'LCWOO_INTEGRATION_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );
				define( 'LCWOO_INTEGRATION_PLUGIN_URL', plugin_dir_url( __FILE__ ) );
				define( 'LCWOO_INTEGRATION_PLUGIN_VER', '1.2.5' );

				add_theme_support( 'woocommerce' ); // Hide message - Declare WooCommerce support in third party theme.

				/**
				 * Include required core files
				 */
				require_once( LCWOO_INTEGRATION_PLUGIN_DIR.'includes/product/lc-woo-product.php' );
				require_once( LCWOO_INTEGRATION_PLUGIN_DIR.'includes/shop/lc-woo-shop.php' );
				require_once( LCWOO_INTEGRATION_PLUGIN_DIR.'includes/cart/lc-woo-cart.php' );
				require_once( LCWOO_INTEGRATION_PLUGIN_DIR.'includes/checkout/lc-woo-checkout.php' );
				require_once( LCWOO_INTEGRATION_PLUGIN_DIR.'includes/account/lc-woo-account.php' );
				require_once( LCWOO_INTEGRATION_PLUGIN_DIR.'includes/common/functions.php' );
			} else {

				/**
				 * Admin Notice
				 */
				function lcwoo_notice_woo_version() {
				?>
				<div class="notice notice-error">
					<p><?php printf( __( 'The "Live Composer - WooCommerce integration" add-on requires WooCommerce 3.0+. %sContact our support team%s if you need a previous version.', 'lcwoo' ), '<a target="_blank" href="https://livecomposerplugin.com/support/">', '</a>' ); ?></p>
				</div>
				<?php }
				add_action( 'admin_notices', 'lcwoo_notice_woo_version' );
			}
		} else {

			/**
			 * Admin Notice
			 */
			function lcwoo_notice_lc_version() {
			?>
			<div class="notice notice-error">
				<p><?php printf( __( '%sCan\'t activate "Live Composer - WooCommerce integration".%s The latest version of %sLive Composer%s plugin required.', 'lcmenupro' ), '<strong>', '</strong>', '<a target="_blank" href="https://wordpress.org/plugins/live-composer-page-builder/">', '</a>' ); ?></p>
			</div>
			<?php }
			add_action( 'admin_notices', 'lcwoo_notice_lc_version' );
		}
	} else {

		/**
		 * Admin Notice
		 */
		function lcwoo_inactive_notice() {
		?>
		<div class="error">
			<p><?php printf( __( 'The WooCommerce extension for Live Composer is activated but in order to work, need to have both %sWooCommerce%s and %sLive Composer%s plugins should be active.', 'lcwoo' ), '<a target="_blank" href="https://wordpress.org/plugins/woocommerce/">', '</a>', '<a target="_blank" href="https://wordpress.org/plugins/live-composer-page-builder/">', '</a>' ); ?></p>
		</div>
		<?php }
		add_action( 'admin_notices', 'lcwoo_inactive_notice' );
	}
} add_action( 'plugins_loaded', 'lcwoo_plugin_init' );


/**
 * Redirect users to the pugin settings on activation. 
 *
 * @return void
 */
function lcwoo_detect_plugin_activation( $plugin ) {
	// ex.: $plugin = akismet/akismet.php

	// Redirection on plugin activation to the settings.
	if ( plugin_basename( __FILE__ ) === $plugin ) {
		// Make Welcome screen optional.
		$show_welcome_screen = true;
		if ( ! apply_filters( 'lcwoo_show_welcome_screen', $show_welcome_screen ) ) {
			return;
		}

		// Bail if activating from network, or bulk.
		if ( is_network_admin() || isset( $_GET['activate-multi'] ) || isset( $_GET['tgmpa-activate'] ) || isset( $_GET['tgmpa-install'] ) ) {
			return;
		}

		wp_safe_redirect( admin_url( 'admin.php?page=dslc_plugin_options&tab=woocommerce' ) );
		exit; // ! important to keep this exit line
		// Function wp_redirect() does not exit automatically and should almost always be followed by exit.
	}

} add_action( 'activated_plugin', 'lcwoo_detect_plugin_activation' );


/**
 * Register plugins that require premium license.
 */
function lcwoo_license_manager_init() {

	// Retrieve old license key from the DB.
	$license_key_old = get_option( 'lcwoo_edd_license_key', false );

	// Migrate old license key to the central key storage.
	if ( $license_key_old ) {
		$license_manager = new LC_License_Manager;
		$license_manager->set_license_key( 'lc-woo-integration', $license_key_old );
		$license_manager->set_license_status( 'lc-woo-integration', 'valid' );

		delete_option( 'lcwoo_edd_license_key' );
	}

	// Require License Manager for Premium Extensions Plugin.
	$lc_license_manager = new LC_License_Manager(
		array(
			'slug' => 'lc-woo-integration',
			'product_id' => 178298,
			'file' => __FILE__,
			'version' => LCWOO_INTEGRATION_PLUGIN_VER,
			'author' => 'Live Composer Team',
		)
	);
} add_action( 'admin_init', 'lcwoo_license_manager_init', 9);
